ble_stack

Function ble_stack 

pub async fn ble_stack() -> &'static mut Stack<'static, DummyController, StaticPacketPool<CriticalSectionRawMutex, trouble_host::::packet_pool::DefaultPacketPool::{constant#0}, trouble_host::::packet_pool::DefaultPacketPool::{constant#1}>>
Available on crate feature ble only.
Returns the system BLE stack, BleStack.

Panics

For this function to succeed, it can only be called from the system executor, and only once:

  • Panics if the stack was already taken.
  • Panics when not called from the system executor.