eui48_from_env

Macro eui48_from_env 

macro_rules! eui48_from_env {
    ($env_var:literal, $doc:literal $(,)?) => { ... };
}
Reads an eui48 at compile time from the given environment variable, produces an [u8; 6], matched to the endianness of the target.

  • The $doc parameter allows to provide a documentation string for this tunable (see str_from_env!).

Errors

  • Produces a compile-time error when option_env! does.
  • Produces a compile-time error when the environment variable cannot be parsed into a eui48