Struct OutputBuilder
pub struct OutputBuilder<'a, T, P>where
T: IntoPeripheral<'a, P>,
P: OutputPin,{ /* private fields */ }Expand description
Builder type for Output, can be obtained with Output::builder().
Implementations
impl<'a, T, P> OutputBuilder<'a, T, P>where
T: IntoPeripheral<'a, P>,
P: OutputPin + 'a,
impl<'a, T, P> OutputBuilder<'a, T, P>where
T: IntoPeripheral<'a, P>,
P: OutputPin + 'a,
pub fn drive_strength(
self,
drive_strength: DriveStrength<DriveStrength>,
) -> OutputBuilder<'a, T, P>
pub fn drive_strength( self, drive_strength: DriveStrength<DriveStrength>, ) -> OutputBuilder<'a, T, P>
Configures the output’s drive strength.
Note
Fails to compile if the HALs does not support configuring drive strength of outputs.
pub fn speed(self, speed: Speed<Speed>) -> OutputBuilder<'a, T, P>
pub fn speed(self, speed: Speed<Speed>) -> OutputBuilder<'a, T, P>
Configures the output’s speed.
Note
Fails to compile if the HAL does not support configuring speed of outputs.
impl<'a, T, P> OutputBuilder<'a, T, P>where
T: IntoPeripheral<'a, P>,
P: OutputPin + 'a,
impl<'a, T, P> OutputBuilder<'a, T, P>where
T: IntoPeripheral<'a, P>,
P: OutputPin + 'a,