Input

Struct Input 

pub struct Input<'a> { /* private fields */ }
A GPIO input.

If support for external interrupts is needed, use InputBuilder::build_with_interrupt() to obtain an IntEnabledInput.

Implementations



impl<'a> Input<'a>

pub fn new<P>(pin: impl IntoPeripheral<'a, P>, pull: Pull) -> Input<'a>
where P: InputPin + 'a,

Returns a configured Input.

If you want to re-use a pin at runtime, you can give the result of .reborrow() of the pin instance to this constructor. This driver and the child pin instance need to be dropped before being able to use the pin in another driver.

pub fn builder<T, P>(pin: T, pull: Pull) -> InputBuilder<'a, T, P>
where T: IntoPeripheral<'a, P>, P: InputPin + 'a,

Returns an InputBuilder, allowing to configure the GPIO input further.

If you want to re-use a pin at runtime, you can give the result of .reborrow() of the pin instance to this constructor. This driver and the child pin instance need to be dropped before being able to use the pin in another driver.

pub fn is_high(&self) -> bool

Returns whether the input level is high.

pub fn is_low(&self) -> bool

Returns whether the input level is low.

pub fn get_level(&self) -> Level

Returns the input level.