UsageType

Enum UsageType 

#[repr(u8)]
pub enum UsageType { DataEndpoint = 0, FeedbackEndpoint = 1, ImplicitFeedbackDataEndpoint = 2, Reserved = 3, }
USB endpoint usage type. The values of this enum can be directly cast into u8 to get the bmAttributes usage type bits. Values other than DataEndpoint are only allowed on isochronous endpoints.

Variants



DataEndpoint = 0

Use the endpoint for regular data transfer.



FeedbackEndpoint = 1

Endpoint conveys explicit feedback information for one or more data endpoints.



ImplicitFeedbackDataEndpoint = 2

A data endpoint that also serves as an implicit feedback endpoint for one or more data endpoints.



Reserved = 3

Reserved usage type.