Label

Enum Label 

#[non_exhaustive]
pub enum Label {
Show 21 variants AccelerationX, AccelerationY, AccelerationZ, Altitude, AngularVelocityX, AngularVelocityY, AngularVelocityZ, Co2, GroundSpeed, Latitude, Longitude, Opaque, OpaqueGnssTime, Pressure, RelativeHumidity, Heading, Temperature, VerticalSpeed, X, Y, Z,
}
Available on crate feature sensors only.
Label of a Sample part of a Samples tuple.

For sensor driver implementors

Missing variants can be added when required. Please open an issue to discuss it.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


AccelerationX

Acceleration along the X axis.



AccelerationY

Acceleration along the Y axis.



AccelerationZ

Acceleration along the Z axis.



Altitude

Altitude.



AngularVelocityX

Angular velocity about the X axis.



AngularVelocityY

Angular velocity about the Y axis.



AngularVelocityZ

Angular velocity about the Z axis.



Co2

CO2 concentration.



GroundSpeed

Ground speed.



Latitude

Latitude.



Longitude

Longitude.



Opaque

Opaque channel: the associated sample is intended for the sensor driver only, and no guarantees are provided.



OpaqueGnssTime

Opaque channel marker used by GnssTimeExt.



Pressure

Pressure.



RelativeHumidity

Relative humidity.



Heading

Heading.



Temperature

Temperature.



VerticalSpeed

Vertical speed.



X

X axis.



Y

Y axis.



Z

Z axis.