Type Alias ThreadFlags
pub type ThreadFlags = u16;Available on crate feature
threading only.Expand description
Bitmask that represent the flags that are set for a thread.
pub type ThreadFlags = u16;threading only.Bitmask that represent the flags that are set for a thread.