Function register_custom_transport
pub fn register_custom_transport(write_bytes_fn: fn(&[u8]), flush_fn: fn())Available on crate feature
custom-transport-driver only.Expand description
Registers a custom transport.
Registering a custom transport requires providing two functions:
write_bytes_fnis used to write bytes to the transport. Depending on the logging facade it may be UTF-8 encoded text or raw binary data.flush_fnis used to flush the data in the transport.
Important note
write_bytes_fn and flush_fn may be executed inside a critical section, disabling interrupts.
They should therefore not wait for interrupts and should not trigger calls to the logging facade.