DfuAttributes

Struct DfuAttributes 

pub struct DfuAttributes { /* private fields */ }
Attributes supported by the DFU controller.

Implementations



impl DfuAttributes

pub const WILL_DETACH: DfuAttributes

Generate WillDetach sequence on bus.

pub const MANIFESTATION_TOLERANT: DfuAttributes

Device can communicate during manifestation phase.

pub const CAN_UPLOAD: DfuAttributes

Capable of upload.

pub const CAN_DOWNLOAD: DfuAttributes

Capable of download.

pub const fn empty() -> DfuAttributes

Returns an empty set of flags.

pub const fn all() -> DfuAttributes

Returns the set containing all flags.

pub const fn bits(&self) -> u8

Returns the raw value of the flags currently stored.

pub const fn from_bits(bits: u8) -> Option<DfuAttributes>

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

pub const fn from_bits_truncate(bits: u8) -> DfuAttributes

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

pub const unsafe fn from_bits_unchecked(bits: u8) -> DfuAttributes

Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).

Safety

The caller of the bitflags! macro can chose to allow or disallow extra bits for their bitflags type.

The caller of from_bits_unchecked() has to ensure that all bits correspond to a defined flag or that extra bits are valid for this bitflags type.

pub const fn is_empty(&self) -> bool

Returns true if no flags are currently stored.

pub const fn is_all(&self) -> bool

Returns true if all flags are currently set.

pub const fn intersects(&self, other: DfuAttributes) -> bool

Returns true if there are flags common to both self and other.

pub const fn contains(&self, other: DfuAttributes) -> bool

Returns true if all of the flags in other are contained within self.

pub fn insert(&mut self, other: DfuAttributes)

Inserts the specified flags in-place.

pub fn remove(&mut self, other: DfuAttributes)

Removes the specified flags in-place.

pub fn toggle(&mut self, other: DfuAttributes)

Toggles the specified flags in-place.

pub fn set(&mut self, other: DfuAttributes, value: bool)

Inserts or removes the specified flags depending on the passed value.

pub const fn intersection(self, other: DfuAttributes) -> DfuAttributes

Returns the intersection between the flags in self and other.

Specifically, the returned set contains only the flags which are present in both self and other.

This is equivalent to using the & operator (e.g. ops::BitAnd), as in flags & other.

pub const fn union(self, other: DfuAttributes) -> DfuAttributes

Returns the union of between the flags in self and other.

Specifically, the returned set contains all flags which are present in either self or other, including any which are present in both (see Self::symmetric_difference if that is undesirable).

This is equivalent to using the | operator (e.g. ops::BitOr), as in flags | other.

pub const fn difference(self, other: DfuAttributes) -> DfuAttributes

Returns the difference between the flags in self and other.

Specifically, the returned set contains all flags present in self, except for the ones present in other.

It is also conceptually equivalent to the “bit-clear” operation: flags & !other (and this syntax is also supported).

This is equivalent to using the - operator (e.g. ops::Sub), as in flags - other.

pub const fn symmetric_difference(self, other: DfuAttributes) -> DfuAttributes

Returns the symmetric difference between the flags in self and other.

Specifically, the returned set contains the flags present which are present in self or other, but that are not present in both. Equivalently, it contains the flags present in exactly one of the sets self and other.

This is equivalent to using the ^ operator (e.g. ops::BitXor), as in flags ^ other.

pub const fn complement(self) -> DfuAttributes

Returns the complement of this set of flags.

Specifically, the returned set contains all the flags which are not set in self, but which are allowed for this type.

Alternatively, it can be thought of as the set difference between Self::all() and self (e.g. Self::all() - self)

This is equivalent to using the ! operator (e.g. ops::Not), as in !flags.